#include "vtkPolyData.h"
#include "vtkSmartPointer.h"
#include "vtkXMLPolyDataReader.h"
#include "vtkXMLPolyDataWriter.h"

#include "vtkPointSetCurvatureEstimation.h"

int main (int argc, char *argv[])
{
  if(argc != 3)
  {
    vtkstd::cout << "Required arguments: InputFilename OutputFilename" << vtkstd::endl;
    exit(-1);
  }
  
  vtkstd::string InputFilename = argv[1];
  vtkstd::string OutputFilename = argv[2];
  
  vtkSmartPointer<vtkXMLPolyDataReader> Reader = vtkSmartPointer<vtkXMLPolyDataReader>::New();
  Reader->SetFileName(InputFilename.c_str());
  Reader->Update();
  
  vtkSmartPointer<vtkPointSetCurvatureEstimation> CurvatureEstimation = vtkSmartPointer<vtkPointSetCurvatureEstimation>::New();
  CurvatureEstimation->SetInput(Reader->GetOutput());
  CurvatureEstimation->Update();
  
  vtkSmartPointer<vtkXMLPolyDataWriter> Writer = vtkSmartPointer<vtkXMLPolyDataWriter>::New();
  Writer->SetFileName(OutputFilename.c_str());
  Writer->SetInput(CurvatureEstimation->GetOutput());
  Writer->Write();
  
  return 0;
}
